@@ -1391,7 +1391,7 @@ void QtTableView::paintEvent( TQPaintEvent *e )
 	TQRect r = viewR;
 	r.setLeft( xPos );
 	r.setBottom( yPos<maxY?yPos:maxY );
-	if ( inherits( TQMULTILINEEDIT_OBJECT_NAME_STRING ) )
+	if ( inherits( "TQMultiLineEdit" ) )
 	    paint.fillRect( r.intersect( updateR ), g.base() );
 	else
 	    paint.eraseRect( r.intersect( updateR ) );
@@ -1399,7 +1399,7 @@ void QtTableView::paintEvent( TQPaintEvent *e )
     if ( yPos <= maxY ) {
 	TQRect r = viewR;
 	r.setTop( yPos );
-	if ( inherits( TQMULTILINEEDIT_OBJECT_NAME_STRING ) )
+	if ( inherits( "TQMultiLineEdit" ) )
 	    paint.fillRect( r.intersect( updateR ), g.base() );
 	else
 	    paint.eraseRect( r.intersect( updateR ) );
@@ -1446,7 +1446,7 @@ TQScrollBar *QtTableView::verticalScrollBar() const
         sb->resize( sb->sizeHint() ); // height is irrelevant
 	TQ_CHECK_PTR(sb);
 	sb->setTracking( FALSE );
-	sb->setFocusPolicy( TQ_NoFocus );
+	sb->setFocusPolicy( TQWidget::NoFocus );
 	connect( sb, TQT_SIGNAL(valueChanged(int)),
 		 TQT_SLOT(verSbValue(int)));
 	connect( sb, TQT_SIGNAL(sliderMoved(int)),
@@ -1475,7 +1475,7 @@ TQScrollBar *QtTableView::horizontalScrollBar() const
 	sb->setCursor( arrowCursor );
 #endif
 	sb->resize( sb->sizeHint() ); // width is irrelevant
-	sb->setFocusPolicy( TQ_NoFocus );
+	sb->setFocusPolicy( TQWidget::NoFocus );
 	TQ_CHECK_PTR(sb);
 	sb->setTracking( FALSE );
 	connect( sb, TQT_SIGNAL(valueChanged(int)),
